Learn R Programming

nplr (version 0.1-8)

nplrAccessors: nplr accessor functions

Description

Methods for extracting information from an object of class nplr. Each of the below methods are simply convenience functions which extract the corresponding slots (as the name of each method suggests) from the object of class nplr.

Arguments

Methods

signature(object = "nplr")

  • getX(object)

  • getY(object)

  • getXcurve(object)

  • getYcurve(object)

  • getFitValues(object)

  • getInflexion(object)

  • getPar(object)

  • getAUC(object)

  • getGoodness(object)

  • getStdErr(object)

  • getWeights(object)

See Also

nplr, getEstimates